@@ -4,16 +4,16 @@
  * Copyright (C) 2001, 2002, 2003, 2006, 2007, 2008 Brailcom, o.p.s.
  *
  * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1, or (at your option)
  * any later version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
@@ -51,23 +51,19 @@
  * installed on the user's system.
  */
 #include <speechd_types.h>
+#include <speechd_defines.h>
 #include "libspeechd.h"
 
 /* Comment/uncomment to switch debugging on/off */
 // #define LIBSPEECHD_DEBUG 1
 
-#ifdef LIBSPEECHD_DEBUG
-/* Debugging */
-static FILE *spd_debug;
-#endif
-
 /* Unless there is an fatal error, it doesn't print anything */
 #define SPD_FATAL(msg) { printf("Fatal error (libspeechd) [%s:%d]:"msg, __FILE__, __LINE__); fflush(stdout); exit(EXIT_FAILURE); }
 
 /* --------------  Private functions headers ------------------------*/
 
 #ifdef LIBSPEECHD_DEBUG
-FILE *spd_debug = NULL;
+static FILE *spd_debug = NULL;
 #endif
 
 static int spd_set_priority(SPDConnection * connection, SPDPriority priority);
@@ -81,6 +77,9 @@ static int ret_ok(char *reply);
 static void SPD_DBG(char *format, ...);
 static void *spd_events_handler(void *);
 
+const int range_low = -100;
+const int range_high = 100;
+
 pthread_mutex_t spd_logging_mutex;
 
 #if !(defined(__GLIBC__) && defined(_GNU_SOURCE))
@@ -165,7 +164,7 @@ static char *_get_default_unix_socket_name(void)
 	return h;
 }
 
-void SPDConnectionAddress__free(SPDConnectionAddress *address)
+void SPDConnectionAddress__free(SPDConnectionAddress * address)
 {
 	if (!address)
 		return;
@@ -382,7 +381,7 @@ spawn_server(SPDConnectionAddress * address, int is_localhost,
 
 SPDConnection *spd_open2(const char *client_name, const char *connection_name,
 			 const char *user_name, SPDConnectionMode mode,
-			 SPDConnectionAddress *address, int autospawn,
+			 SPDConnectionAddress * address, int autospawn,
 			 char **error_result)
 {
 	SPDConnection *connection;
@@ -534,8 +533,7 @@ SPDConnection *spd_open2(const char *client_name, const char *connection_name,
 		    ("Initializing threads, condition variables and mutexes...");
 		connection->events_thread = malloc(sizeof(pthread_t));
 		connection->cond_reply_ready = malloc(sizeof(pthread_cond_t));
-		connection->mutex_reply_ready =
-		    malloc(sizeof(pthread_mutex_t));
+		connection->mutex_reply_ready = malloc(sizeof(pthread_mutex_t));
 		connection->cond_reply_ack = malloc(sizeof(pthread_cond_t));
 		connection->mutex_reply_ack = malloc(sizeof(pthread_mutex_t));
 		pthread_cond_init(connection->cond_reply_ready, NULL);
@@ -566,10 +564,10 @@ SPDConnection *spd_open2(const char *client_name, const char *connection_name,
 }
 
 #define RET(r) \
-    { \
-    pthread_mutex_unlock(connection->ssip_mutex); \
-    return r; \
-    }
+	{ \
+		pthread_mutex_unlock(connection->ssip_mutex); \
+		return r; \
+	}
 
 /* Close a Speech Dispatcher connection */
 void spd_close(SPDConnection * connection)
@@ -976,28 +974,28 @@ spd_w_set_voice_type(SPDConnection * connection, SPDVoiceType type,
 
 	switch (type) {
 	case SPD_MALE1:
-		sprintf(command, "SET %s VOICE MALE1", who);
+		sprintf(command, "SET %s VOICE_TYPE MALE1", who);
 		break;
 	case SPD_MALE2:
-		sprintf(command, "SET %s VOICE MALE2", who);
+		sprintf(command, "SET %s VOICE_TYPE MALE2", who);
 		break;
 	case SPD_MALE3:
-		sprintf(command, "SET %s VOICE MALE3", who);
+		sprintf(command, "SET %s VOICE_TYPE MALE3", who);
 		break;
 	case SPD_FEMALE1:
-		sprintf(command, "SET %s VOICE FEMALE1", who);
+		sprintf(command, "SET %s VOICE_TYPE FEMALE1", who);
 		break;
 	case SPD_FEMALE2:
-		sprintf(command, "SET %s VOICE FEMALE2", who);
+		sprintf(command, "SET %s VOICE_TYPE FEMALE2", who);
 		break;
 	case SPD_FEMALE3:
-		sprintf(command, "SET %s VOICE FEMALE3", who);
+		sprintf(command, "SET %s VOICE_TYPE FEMALE3", who);
 		break;
 	case SPD_CHILD_MALE:
-		sprintf(command, "SET %s VOICE CHILD_MALE", who);
+		sprintf(command, "SET %s VOICE_TYPE CHILD_MALE", who);
 		break;
 	case SPD_CHILD_FEMALE:
-		sprintf(command, "SET %s VOICE CHILD_FEMALE", who);
+		sprintf(command, "SET %s VOICE_TYPE CHILD_FEMALE", who);
 		break;
 	default:
 		return -1;
@@ -1006,98 +1004,261 @@ spd_w_set_voice_type(SPDConnection * connection, SPDVoiceType type,
 	return spd_execute_command(connection, command);
 }
 
-#define SPD_SET_COMMAND_INT(param, ssip_name, condition) \
-    int \
-    spd_w_set_ ## param (SPDConnection *connection, signed int val, const char* who) \
-    { \
-        static char command[64]; \
-        if ((!condition)) return -1; \
-        sprintf(command, "SET %s " #ssip_name " %d", who, val); \
-        return spd_execute_command(connection, command); \
-    } \
-    int \
-    spd_set_ ## param (SPDConnection *connection, signed int val) \
-    { \
-        return spd_w_set_ ## param (connection, val, "SELF"); \
-    } \
-    int \
-    spd_set_ ## param ## _all(SPDConnection *connection, signed int val) \
-    { \
-        return spd_w_set_ ## param (connection, val, "ALL"); \
-    } \
-    int \
-    spd_set_ ## param ## _uid(SPDConnection *connection, signed int val, unsigned int uid) \
-    { \
-        char who[8]; \
-        sprintf(who, "%d", uid); \
-        return spd_w_set_ ## param (connection, val, who); \
-    }
+static int spd_w_set_command_int(SPDConnection * connection,
+				 const char *ssip_name, signed int val,
+				 const char *who)
+{
+	static char command[64];
+	// NOTE: if any new int ssip_name are added that don't use -100 - 100 as their
+	// range, these values will need to become parameters (or the new ssip_name)
+	// methods will need to call a different helper method.
+	if (val < range_low || val > range_high)
+		return -1;
+	sprintf(command, "SET %s %s %d", who, ssip_name, val);
+	return spd_execute_command(connection, command);
+}
 
-#define SPD_SET_COMMAND_STR(param, ssip_name) \
-    int \
-    spd_w_set_ ## param (SPDConnection *connection, const char *str, const char* who) \
-    { \
-        char *command; \
-        int ret; \
-        if (str == NULL) return -1; \
-        command = g_strdup_printf("SET %s " #param " %s", \
-                              who, str); \
-        ret = spd_execute_command(connection, command); \
-        free(command); \
-        return ret; \
-    } \
-    int \
-    spd_set_ ## param (SPDConnection *connection, const char *str) \
-    { \
-        return spd_w_set_ ## param (connection, str, "SELF"); \
-    } \
-    int \
-    spd_set_ ## param ## _all(SPDConnection *connection, const char *str) \
-    { \
-        return spd_w_set_ ## param (connection, str, "ALL"); \
-    } \
-    int \
-    spd_set_ ## param ## _uid(SPDConnection *connection, const char *str, unsigned int uid) \
-    { \
-        char who[8]; \
-        sprintf(who, "%d", uid); \
-        return spd_w_set_ ## param (connection, str, who); \
-    }
+static int spd_get_command_int(SPDConnection * connection,
+			       const char *ssip_name)
+{
+	char *command;
+	int ret = 0;
+	int err;
+	char *reply = NULL;
+	command = g_strdup_printf("GET %s", ssip_name);
+	spd_execute_command_with_reply(connection, command, &reply);
+	free(command);
+	ret = get_param_int(reply, 1, &err);
+	free(reply);
+	return ret;
+}
+
+static int spd_w_set_command_str(SPDConnection * connection,
+				 const char *ssip_name, const char *str,
+				 const char *who)
+{
+	char *command;
+	int ret;
+	if (str == NULL)
+		return -1;
+	command = g_strdup_printf("SET %s %s %s", who, ssip_name, str);
+	ret = spd_execute_command(connection, command);
+	free(command);
+	return ret;
+}
+
+static char *spd_get_command_str(SPDConnection * connection,
+				 const char *ssip_name)
+{
+	char *command;
+	char *ret = NULL;
+	int err;
+	char *reply = NULL;
+	command = g_strdup_printf("GET %s", ssip_name);
+	spd_execute_command_with_reply(connection, command, &reply);
+	free(command);
+	ret = get_param_str(reply, 1, &err);
+	free(reply);
+	return ret;
+}
 
 #define SPD_SET_COMMAND_SPECIAL(param, type) \
-    int \
-    spd_set_ ## param (SPDConnection *connection, type val) \
-    { \
-        return spd_w_set_ ## param (connection, val, "SELF"); \
-    } \
-    int \
-    spd_set_ ## param ## _all(SPDConnection *connection, type val) \
-    { \
-        return spd_w_set_ ## param (connection, val, "ALL"); \
-    } \
-    int \
-    spd_set_ ## param ## _uid(SPDConnection *connection, type val, unsigned int uid) \
-    { \
-        char who[8]; \
-        sprintf(who, "%d", uid); \
-        return spd_w_set_ ## param (connection, val, who); \
-    }
+	int \
+	spd_set_ ## param (SPDConnection *connection, type val) \
+	{ \
+		return spd_w_set_ ## param (connection, val, SPD_SELF); \
+	} \
+	int \
+	spd_set_ ## param ## _all(SPDConnection *connection, type val) \
+	{ \
+		return spd_w_set_ ## param (connection, val, SPD_ALLCLIENTS); \
+	} \
+	int \
+	spd_set_ ## param ## _uid(SPDConnection *connection, type val, unsigned int uid) \
+	{ \
+		char who[8]; \
+		sprintf(who, "%d", uid); \
+		return spd_w_set_ ## param (connection, val, who); \
+	}
 
-SPD_SET_COMMAND_INT(voice_rate, RATE, ((val >= -100) && (val <= +100)))
-    SPD_SET_COMMAND_INT(voice_pitch, PITCH, ((val >= -100) && (val <= +100)))
-    SPD_SET_COMMAND_INT(volume, VOLUME, ((val >= -100) && (val <= +100)))
+#define SPD_GET_COMMAND_SPECIAL(param, type) \
+	type \
+	spd_get_ ## param (SPDConnection *connection) \
+	{ \
+		char *command; \
+		type ret; \
+		int err; \
+		char *reply = NULL; \
+		command = g_strdup_printf("GET " #param); \
+		spd_execute_command_with_reply(connection, command, &reply); \
+		free(command); \
+		ret = get_param_int(reply, 1, &err); \
+		free(reply); \
+		return ret; \
+	}
 
-    SPD_SET_COMMAND_STR(language, LANGUAGE)
-    SPD_SET_COMMAND_STR(output_module, OUTPUT_MODULE)
-    SPD_SET_COMMAND_STR(synthesis_voice, SYNTHESIS_VOICE)
+// Set methods for rate
+int spd_set_voice_rate(SPDConnection * connection, signed int rate)
+{
+	return spd_w_set_command_int(connection, SPD_RATE, rate, SPD_SELF);
+}
 
-    SPD_SET_COMMAND_SPECIAL(punctuation, SPDPunctuation)
+int spd_set_voice_rate_all(SPDConnection * connection, signed int rate)
+{
+	return spd_w_set_command_int(connection, SPD_RATE, rate,
+				     SPD_ALLCLIENTS);
+}
+
+int spd_set_voice_rate_uid(SPDConnection * connection, signed int rate,
+			   unsigned int uid)
+{
+	char who[8];
+	sprintf(who, "%d", uid);
+	return spd_w_set_command_int(connection, SPD_RATE, rate, who);
+}
+
+// Get method for rate
+int spd_get_voice_rate(SPDConnection * connection)
+{
+	return spd_get_command_int(connection, SPD_RATE);
+}
+
+// Set methods for pitch
+int spd_set_voice_pitch(SPDConnection * connection, signed int pitch)
+{
+	return spd_w_set_command_int(connection, SPD_PITCH, pitch, SPD_SELF);
+}
+
+int spd_set_voice_pitch_all(SPDConnection * connection, signed int pitch)
+{
+	return spd_w_set_command_int(connection, SPD_PITCH, pitch,
+				     SPD_ALLCLIENTS);
+}
+
+int spd_set_voice_pitch_uid(SPDConnection * connection, signed int pitch,
+			    unsigned int uid)
+{
+	char who[8];
+	sprintf(who, "%d", uid);
+	return spd_w_set_command_int(connection, SPD_PITCH, pitch, who);
+}
+
+// Get method for pitch
+int spd_get_voice_pitch(SPDConnection * connection)
+{
+	return spd_get_command_int(connection, SPD_PITCH);
+}
+
+// Set methods for volume
+int spd_set_volume(SPDConnection * connection, signed int volume)
+{
+	return spd_w_set_command_int(connection, SPD_VOLUME, volume, SPD_SELF);
+}
+
+int spd_set_volume_all(SPDConnection * connection, signed int volume)
+{
+	return spd_w_set_command_int(connection, SPD_VOLUME, volume,
+				     SPD_ALLCLIENTS);
+}
+
+int spd_set_volume_uid(SPDConnection * connection, signed int volume,
+		       unsigned int uid)
+{
+	char who[8];
+	sprintf(who, "%d", uid);
+	return spd_w_set_command_int(connection, SPD_VOLUME, volume, who);
+}
+
+// Get method for volume
+int spd_get_volume(SPDConnection * connection)
+{
+	return spd_get_command_int(connection, SPD_VOLUME);
+}
+
+// Set methods for language
+int spd_set_language(SPDConnection * connection, const char *language)
+{
+	return spd_w_set_command_str(connection, SPD_LANGUAGE, language,
+				     SPD_SELF);
+}
+
+int spd_set_language_all(SPDConnection * connection, const char *language)
+{
+	return spd_w_set_command_str(connection, SPD_LANGUAGE, language,
+				     SPD_ALLCLIENTS);
+}
+
+int spd_set_language_uid(SPDConnection * connection, const char *language,
+			 unsigned int uid)
+{
+	char who[8];
+	sprintf(who, "%d", uid);
+	return spd_w_set_command_str(connection, SPD_LANGUAGE, language, who);
+}
+
+// Get method for language
+char *spd_get_language(SPDConnection * connection)
+{
+	return spd_get_command_str(connection, SPD_LANGUAGE);
+}
+
+// Set methods for output_module
+int spd_set_output_module(SPDConnection * connection, const char *output_module)
+{
+	return spd_w_set_command_str(connection, SPD_OUTPUT_MODULE,
+				     output_module, SPD_SELF);
+}
+
+int spd_set_output_module_all(SPDConnection * connection,
+			      const char *output_module)
+{
+	return spd_w_set_command_str(connection, SPD_OUTPUT_MODULE,
+				     output_module, SPD_ALLCLIENTS);
+}
+
+int spd_set_output_module_uid(SPDConnection * connection,
+			      const char *output_module, unsigned int uid)
+{
+	char who[8];
+	sprintf(who, "%d", uid);
+	return spd_w_set_command_str(connection, SPD_OUTPUT_MODULE,
+				     output_module, who);
+}
+
+// Get method for output_module
+char *spd_get_output_module(SPDConnection * connection)
+{
+	return spd_get_command_str(connection, SPD_OUTPUT_MODULE);
+}
+
+// Set methods for synthesis_voice
+int spd_set_synthesis_voice(SPDConnection * connection, const char *voice_name)
+{
+	return spd_w_set_command_str(connection, SPD_SYNTHESIS_VOICE,
+				     voice_name, SPD_SELF);
+}
+
+int spd_set_synthesis_voice_all(SPDConnection * connection,
+				const char *voice_name)
+{
+	return spd_w_set_command_str(connection, SPD_SYNTHESIS_VOICE,
+				     voice_name, SPD_ALLCLIENTS);
+}
+
+int spd_set_synthesis_voice_uid(SPDConnection * connection,
+				const char *voice_name, unsigned int uid)
+{
+	char who[8];
+	sprintf(who, "%d", uid);
+	return spd_w_set_command_str(connection, SPD_SYNTHESIS_VOICE,
+				     voice_name, who);
+}
+
+SPD_SET_COMMAND_SPECIAL(punctuation, SPDPunctuation)
     SPD_SET_COMMAND_SPECIAL(capital_letters, SPDCapitalLetters)
     SPD_SET_COMMAND_SPECIAL(spelling, SPDSpelling)
     SPD_SET_COMMAND_SPECIAL(voice_type, SPDVoiceType)
-
-#undef SPD_SET_COMMAND_INT
-#undef SPD_SET_COMMAND_STR
+    SPD_GET_COMMAND_SPECIAL(voice_type, SPDVoiceType)
 #undef SPD_SET_COMMAND_SPECIAL
 int
 spd_set_notification_on(SPDConnection * connection,
@@ -1120,11 +1281,11 @@ spd_set_notification_off(SPDConnection * connection,
 }
 
 #define NOTIFICATION_SET(val, ssip_val) \
-    if (notification & val){ \
-	sprintf(command, "SET SELF NOTIFICATION "ssip_val" %s", state);\
-	ret = spd_execute_command_wo_mutex(connection, command);\
-	if (ret < 0) RET(-1);\
-    }
+	if (notification & val){ \
+		sprintf(command, "SET SELF NOTIFICATION "ssip_val" %s", state);\
+		ret = spd_execute_command_wo_mutex(connection, command);\
+		if (ret < 0) RET(-1);\
+	}
 
 int
 spd_set_notification(SPDConnection * connection, SPDNotification notification,
@@ -1176,6 +1337,16 @@ char **spd_list_modules(SPDConnection * connection)
 	return available_modules;
 }
 
+void free_spd_modules(char **modules)
+{
+	int i = 0;
+	while (modules != NULL && modules[i] != NULL) {
+		free(modules[i]);
+		++i;
+	}
+	free(modules);
+}
+
 char **spd_list_voices(SPDConnection * connection)
 {
 	char **voices;
@@ -1221,6 +1392,17 @@ SPDVoice **spd_list_synthesis_voices(SPDConnection * connection)
 	return svoices;
 }
 
+void free_spd_voices(SPDVoice ** voices)
+{
+	int i = 0;
+	while (voices != NULL && voices[i] != NULL) {
+		free(voices[i]->name);
+		free(voices[i]);
+		++i;
+	}
+	free(voices);
+}
+
 char **spd_execute_command_with_list_reply(SPDConnection * connection,
 					   char *command)
 {
@@ -1274,11 +1456,11 @@ spd_get_message_list_fd(SPDConnection * connection, int target, int *msg_ids,
 	sprintf(command, "HISTORY GET MESSAGE_LIST %d 0 20\r\n", target);
 	reply = spd_send_data(fd, command, 1);
 
-/*	header_ok = parse_response_header(reply);
-	if(header_ok != 1){
-		free(reply);
-		return -1;
-	}*/
+	/*      header_ok = parse_response_header(reply);
+	   if(header_ok != 1){
+	   free(reply);
+	   return -1;
+	   } */
 
 	for (count = 0;; count++) {
 		record = (char *)parse_response_data(reply, count + 1);
