@@ -47,7 +47,6 @@
 #include <speechd_types.h>
 #include "module_utils.h"
 
-
 /* > */
 /* < Basic definitions*/
 
@@ -155,10 +154,6 @@ static void espeak_set_volume(signed int volume);
 static void espeak_set_punctuation_mode(SPDPunctuation punct_mode);
 static void espeak_set_cap_let_recogn(SPDCapitalLetters cap_mode);
 
-#if 0
-static void espeak_set_pitch_range(signed int pitch_range);
-#endif
-
 /* Voices and languages */
 static void espeak_set_language(char *lang);
 static void espeak_set_voice(SPDVoiceType voice);
@@ -188,12 +183,12 @@ static void *_espeak_stop_or_pause(void *);
 /* > */
 /* < Module configuration options*/
 
-MOD_OPTION_1_INT(EspeakPitchRange)
-    MOD_OPTION_1_STR(EspeakPunctuationList)
+MOD_OPTION_1_STR(EspeakPunctuationList)
     MOD_OPTION_1_INT(EspeakCapitalPitchRise)
     MOD_OPTION_1_INT(EspeakMinRate)
     MOD_OPTION_1_INT(EspeakNormalRate)
     MOD_OPTION_1_INT(EspeakMaxRate)
+    MOD_OPTION_1_INT(EspeakListVoiceVariants)
 
     MOD_OPTION_1_INT(EspeakAudioChunkSize)
     MOD_OPTION_1_INT(EspeakAudioQueueMaxSize)
@@ -215,12 +210,12 @@ int module_load(void)
 			     "/usr/share/sounds/sound-icons/");
 	MOD_OPTION_1_INT_REG(EspeakSoundIconVolume, 0);
 
-	MOD_OPTION_1_INT_REG(EspeakPitchRange, 0);
 	MOD_OPTION_1_INT_REG(EspeakMinRate, 80);
 	MOD_OPTION_1_INT_REG(EspeakNormalRate, 170);
 	MOD_OPTION_1_INT_REG(EspeakMaxRate, 390);
 	MOD_OPTION_1_STR_REG(EspeakPunctuationList, "@/+-_");
 	MOD_OPTION_1_INT_REG(EspeakCapitalPitchRise, 800);
+	MOD_OPTION_1_INT_REG(EspeakListVoiceVariants, 0);
 	if (EspeakCapitalPitchRise == 1 || EspeakCapitalPitchRise == 2) {
 		EspeakCapitalPitchRise = 0;
 	}
@@ -365,8 +360,7 @@ int module_speak(gchar * data, size_t bytes, SPDMessageType msgtype)
 		result = espeak_Synth(data, bytes + 1, 0, POS_CHARACTER, 0,
 				      flags, NULL, NULL);
 		break;
-	case SPD_MSGTYPE_SOUND_ICON:
-		{
+	case SPD_MSGTYPE_SOUND_ICON:{
 			char *msg =
 			    g_strdup_printf("<audio src=\"%s%s\">%s</audio>",
 					    EspeakSoundIconFolder, data, data);
@@ -376,8 +370,7 @@ int module_speak(gchar * data, size_t bytes, SPDMessageType msgtype)
 			g_free(msg);
 			break;
 		}
-	case SPD_MSGTYPE_CHAR:
-		{
+	case SPD_MSGTYPE_CHAR:{
 			wchar_t wc = 0;
 			if (bytes == 1) {	// ASCII
 				wc = (wchar_t) data[0];
@@ -407,8 +400,7 @@ int module_speak(gchar * data, size_t bytes, SPDMessageType msgtype)
 			g_free(msg);
 			break;
 		}
-	case SPD_MSGTYPE_KEY:
-		{
+	case SPD_MSGTYPE_KEY:{
 			/* TODO: Convert unspeakable keys to speakable form */
 			char *msg =
 			    g_strdup_printf
@@ -607,7 +599,8 @@ static void espeak_set_rate(signed int rate)
 {
 	assert(rate >= -100 && rate <= +100);
 	int speed;
-	int normal_rate = EspeakNormalRate, max_rate = EspeakMaxRate, min_rate = EspeakMinRate;
+	int normal_rate = EspeakNormalRate, max_rate = EspeakMaxRate, min_rate =
+	    EspeakMinRate;
 
 	if (rate < 0)
 		speed = normal_rate + (normal_rate - min_rate) * rate / 100;
@@ -820,8 +813,7 @@ static int synth_callback(short *wav, int numsamples, espeak_EVENT * events)
 		/* Enqueue audio upto event */
 		switch (events->type) {
 		case espeakEVENT_MARK:
-		case espeakEVENT_PLAY:
-			{
+		case espeakEVENT_PLAY:{
 				/* Convert ms position to samples */
 				gint64 pos_msg = events->audio_position;
 				pos_msg = pos_msg * espeak_sample_rate / 1000;
@@ -844,8 +836,8 @@ static int synth_callback(short *wav, int numsamples, espeak_EVENT * events)
 			break;
 		case espeakEVENT_PLAY:
 			result =
-			    espeak_add_sound_icon_to_playback_queue(events->id.
-								    name);
+			    espeak_add_sound_icon_to_playback_queue(events->
+								    id.name);
 			break;
 		case espeakEVENT_MSG_TERMINATED:
 			// This event never has any audio in the same callback
@@ -870,11 +862,9 @@ static int uri_callback(int type, const char *uri, const char *base)
 	int result = 1;
 	if (type == 1) {
 		/* Audio icon */
-#if HAVE_SNDFILE
 		if (g_file_test(uri, G_FILE_TEST_EXISTS)) {
 			result = 0;
 		}
-#endif
 	}
 	return result;
 }
@@ -1095,11 +1085,10 @@ static void *_espeak_play(void *nothing)
 				pthread_mutex_unlock(&espeak_state_mutex);
 				break;
 			case ESPEAK_QET_SOUND_ICON:
-				module_play_file(playback_queue_entry->data.
-						 sound_icon_filename);
+				module_play_file(playback_queue_entry->
+						 data.sound_icon_filename);
 				break;
-			case ESPEAK_QET_BEGIN:
-				{
+			case ESPEAK_QET_BEGIN:{
 					gboolean report_begin = FALSE;
 					pthread_mutex_lock(&espeak_state_mutex);
 					if (espeak_state == BEFORE_PLAY) {
@@ -1140,35 +1129,46 @@ static void *_espeak_play(void *nothing)
 	return 0;
 }
 
-
 static SPDVoice **espeak_list_synthesis_voices()
 {
 	SPDVoice **result = NULL;
-	const espeak_VOICE **espeak_voices = espeak_ListVoices(NULL);
-	int i = 0;
-	int j = 0;
-
-	/* Count number of voices */
+	SPDVoice *voice = NULL;
+	SPDVoice *vo = NULL;
+	const espeak_VOICE **espeak_voices = NULL;
+	const espeak_VOICE **espeak_variants = NULL;
+	espeak_VOICE *variant_spec = NULL;
+	const espeak_VOICE *v = NULL;
+	GQueue *voice_list = NULL;
+	GQueue *variant_list = NULL;
+	GList *voice_list_iter = NULL;
+	GList *variant_list_iter = NULL;
+	const gchar *first_lang = NULL;
+	gchar *lang = NULL;
+	gchar *variant = NULL;
+	gchar *dash = NULL;
+	gchar *vname = NULL;
 	int numvoices = 0;
-	while (espeak_voices[numvoices] != NULL) {
-		numvoices++;
-	}
-	DBG("Espeak: %d voices total.", numvoices);
-	result = g_new0(SPDVoice *, numvoices + 1);
-	for (i = j = 0; espeak_voices[i] != NULL; i++) {
-		const espeak_VOICE *v = espeak_voices[i];
+	int numvariants = 0;
+	int totalvoices = 0;
+	int i = 0;
+
+	espeak_voices = espeak_ListVoices(NULL);
+	voice_list = g_queue_new();
+
+	for (i = 0; espeak_voices[i] != NULL; i++) {
+		v = espeak_voices[i];
 		if (!g_str_has_prefix(v->identifier, "mb/")) {
 			/* Not an mbrola voice */
-			SPDVoice *voice = g_new0(SPDVoice, 1);
+			voice = g_new0(SPDVoice, 1);
 
 			voice->name = g_strdup(v->name);
 
-			const gchar *first_lang = v->languages + 1;
-			gchar *lang = NULL;
-			gchar *variant = NULL;
+			first_lang = v->languages + 1;
+			lang = NULL;
+			variant = NULL;
 			if (g_utf8_validate(first_lang, -1, NULL)) {
-				gchar *dash =
-				    g_utf8_strchr(first_lang, -1, '-');
+				dash =
+				       g_utf8_strchr(first_lang, -1, '-');
 				if (dash != NULL) {
 					/* There is probably a variant string (like en-uk) */
 					lang =
@@ -1186,11 +1186,67 @@ static SPDVoice **espeak_list_synthesis_voices()
 			voice->language = lang;
 			voice->variant = variant;
 
-			result[j++] = voice;
+			g_queue_push_tail(voice_list, voice);
 		}
+
 	}
-	result[j] = NULL;
-	DBG("Espeak: %d usable voices.", j);
+
+	numvoices = g_queue_get_length(voice_list);
+	DBG("Espeak: %d voices total.", numvoices)
+
+	if (EspeakListVoiceVariants) {
+		variant_spec = g_new0(espeak_VOICE, 1);
+		variant_spec->languages = "variant";
+		espeak_variants = espeak_ListVoices(variant_spec);
+		variant_list = g_queue_new();
+
+		for (i = 0; espeak_variants[i] != NULL; i++) {
+			v = espeak_variants[i];
+
+			vname = g_strdup(v->name);
+			g_queue_push_tail(variant_list, vname);
+		}
+
+		numvariants = g_queue_get_length(variant_list);
+		DBG("Espeak: %d variants total.", numvariants)
+	}
+
+	totalvoices = (numvoices * numvariants) + numvoices;
+	result = g_new0(SPDVoice *, totalvoices + 1);
+	voice_list_iter = g_queue_peek_head_link(voice_list);
+
+	for (i = 0; i < totalvoices; i++) {
+		result[i] = voice_list_iter->data;
+
+		if (!g_queue_is_empty(variant_list)) {
+			vo = voice_list_iter->data;
+			variant_list_iter = g_queue_peek_head_link(variant_list);
+
+			while (variant_list_iter != NULL && variant_list_iter->data != NULL) {
+				voice = g_new0(SPDVoice, 1);
+
+				voice->name = g_strdup_printf("%s+%s", vo->name,
+							      variant_list_iter->data);
+				voice->language = g_strdup(vo->language);
+				voice->variant = g_strdup(vo->variant);
+
+				result[++i] = voice;
+				variant_list_iter = variant_list_iter->next;
+			}
+		}
+
+		voice_list_iter = voice_list_iter->next;
+	}
+
+	if (voice_list != NULL)
+		g_queue_free(voice_list);
+	if (variant_list != NULL)
+		g_queue_free_full(variant_list, (GDestroyNotify)g_free);
+	if (variant_spec != NULL)
+		g_free(variant_spec);
+
+	result[i] = NULL;
+	DBG("Espeak: %d usable voices.", totalvoices);
 
 	return result;
 }
