@@ -19,33 +19,32 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: history.h,v 1.11 2006/07/11 16:12:27 hanke Exp $
+ * $Id: history.h,v 1.11 2006-07-11 16:12:27 hanke Exp $
  */
 
 #ifndef HISTORY_H
- #define HISTORY_H
+#define HISTORY_H
 
 #include "speechd.h"
 
-char* history_get_client_list();
-char* history_get_message_list(guint client_id, int from, int num);
-char* history_get_last(int fd);
-char* history_cursor_set_last(int fd, guint client_id);
-char* history_cursor_set_first(int fd, guint client_id);
-char* history_cursor_set_pos(int fd, guint client_id, int pos);
-char* history_cursor_next(int fd);
-char* history_cursor_prev(int fd);
-char* history_cursor_get(int fd);
-char* history_cursor_forward(int fd);
-char* history_cursor_backward(int fd);
-char* history_say_id(int fd, int id);
-char* history_get_client_id(int fd);
-char* history_get_message(int uid);
+char *history_get_client_list();
+char *history_get_message_list(guint client_id, int from, int num);
+char *history_get_last(int fd);
+char *history_cursor_set_last(int fd, guint client_id);
+char *history_cursor_set_first(int fd, guint client_id);
+char *history_cursor_set_pos(int fd, guint client_id, int pos);
+char *history_cursor_next(int fd);
+char *history_cursor_prev(int fd);
+char *history_cursor_get(int fd);
+char *history_cursor_forward(int fd);
+char *history_cursor_backward(int fd);
+char *history_say_id(int fd, int id);
+char *history_get_client_id(int fd);
+char *history_get_message(int uid);
+int history_add_message(TSpeechDMessage * msg);
 
 /* Internal functions */
-GList* get_messages_by_client(int uid);
-int message_compare_id (gconstpointer element, gconstpointer value, gpointer n);
-
+GList *get_messages_by_client(int uid);
+gint message_compare_id(gconstpointer element, gconstpointer value);
 
 #endif /* HISTORY_H */
-
